Learn R Programming

idx2r (version 1.0.0)

idx2r-package: Convert Files to and from IDX Format to Vectors, Matrices and Arrays in R

Description

Convert files to and from IDX format to arrays in R. IDX is a format to store vector and arrays in binary format. Reading IDX format is needed for instance to use the MNIST database of handwritten digits from http://yann.lecun.com/exdb/mnist/ provided by Yann LeCun.

Arguments

See Also

Useful links:

Examples

Run this code
# NOT RUN {
m = matrix(1:16, nrow = 4)
file_name = file.path(tempdir(),"m.idx")
write_idx(m, file_name)
mr = read_idx(file_name)
# }

Run the code above in your browser using DataLab